(define-module (ui drweb ajax)
    :use-module (alterator woo)
    :use-module (alterator ajax)
    :use-module (alterator str)
  :export (init))

(define (change_daemon)
    (catch/message
    (lambda() (woo-write "/drweb/daemon" 'status (form-value "daemon"))))
    (form-update-value-list
      '("cur_status" ) (woo-read-first "/drweb/status")))

(define (restart_daemon)
    (catch/message
    (lambda() (woo-write "/drweb/daemon" 'status #f)))
    (form-update-value-list
      '("cur_status" ) (woo-read-first "/drweb/status"))

    (catch/message
    (lambda() (woo-write "/drweb/daemon" 'status #t)))
    (form-update-value-list
      '("cur_status" ) (woo-read-first "/drweb/status"))
)

(define (inspect)
    (form-replace "/drweb/quarantine"))

(define (ui-init)
    (form-update-value-list
      '("daemon" "cur_status" "enable_updates" "update_period" "module_drwebd" "module_monitor"
      "quarantine_status" "update_date" "update_time" "enable_samba")
      (woo-read-first "/drweb/status" 
      'language (form-value "language")))
      (key_status)
)

(define (on-upload)
   (call-with-form-file "key_file"
	(lambda(path)
	  (catch/message
	    (lambda()
	       (woo-new "/drweb/key" 'key_file path)
	       ))))
   (let* ((data (woo-read "/drweb/newkey"))
	 (new_Version (and (pair? data) (woo-get-option (car data) 'Version)))
	 (new_Applications (and (pair? data) (woo-get-option (car data) 'Applications)))
	 (new_Created (and (pair? data) (woo-get-option (car data) 'Created)))
	 (new_Expires (and (pair? data) (woo-get-option (car data) 'Expires)))
	 (new_SubscriptionExpires (and (pair? data) (woo-get-option (car data) 'SubscriptionExpires)))
	 (new_Alert (and (pair? data) (woo-get-option (car data) 'Alert)))
	 )
       (form-update-value "new_key_Header" (_ "New Key"))
       (form-update-value "new_Version" new_Version)
       (form-update-value "new_Applications" new_Applications)
       (form-update-value "new_Created" new_Created)
       (form-update-value "new_Expires" new_Expires)
       (form-update-value "new_SubscriptionExpires" new_SubscriptionExpires)
       (form-update-value "new_Alert" new_Alert)
    )
    
)         

(define (write_key)
    (catch/message
	(lambda()
    	    (woo-write "/drweb/newkey")))
    (key_status)
       (form-update-value "new_Version" "")
       (form-update-value "new_Applications" "")
       (form-update-value "new_Created" "")
       (form-update-value "new_Expires" "")
       (form-update-value "new_SubscriptionExpires" "")
       (form-update-value "key_file" "")
       (form-update-value "new_key_Header" "")
	(form-update-value "new_Alert" "")
    
)

(define (drop_key)
    (catch/message
	(lambda()
    	    (woo-delete "/drweb/newkey")))
)

(define (key_status)
   (let* ((data (woo-read  "/drweb/key"))
	 (old_Version (and (pair? data) (woo-get-option (car data) 'Version)))
	 (old_Applications (and (pair? data) (woo-get-option (car data) 'Applications)))
	 (old_Created (and (pair? data) (woo-get-option (car data) 'Created)))
	 (old_Expires (and (pair? data) (woo-get-option (car data) 'Expires)))
	 (old_Alert (and (pair? data) (woo-get-option (car data) 'Alert)))
	 (old_SubscriptionExpires (and (pair? data) (woo-get-option (car data) 'SubscriptionExpires)))
	)
       (form-update-value "old_Version" old_Version)
       (form-update-value "old_Applications" old_Applications)
       (form-update-value "old_Created" old_Created)
       (form-update-value "old_Expires" old_Expires)
       (form-update-value "old_Alert" old_Alert)
       (form-update-value "old_SubscriptionExpires" old_SubscriptionExpires)
))

(define (change_cron)
    (catch/message
	(lambda() (woo-write "/drweb/crontab" 
	    'time (form-value "update_period"))))
)

(define (change_crontab)
    (catch/message
	(lambda() (woo-write "/drweb/cron" 'cron (form-value "enable_updates"))))
    (form-update-activity "update_period" (form-value "enable_updates"))
)

(define (update_bases)
    (catch/message
	(lambda() (woo-write "/drweb/update" )))
)

(define (write_samba)
  (catch/message
    (lambda() (woo-write "/drweb/samba" 'enable_samba (form-value "enable_samba")))))

(define (init)
  (if (woo-get-option (woo-read-first "/drweb/installed") 'installed)
      (begin
         (form-update-visibility "main" #t)
         (form-update-visibility "alert" #f)
     (form-update-activity "enable_samba" (woo-get-option
                                             (woo-read-first "/drweb/drwebsambainstalled") 'drwebsambainstalled))
	 (ui-init)
	 (form-bind "daemon" "change" change_daemon)
	 (form-bind "enable_updates" "change" change_crontab)
	 (form-bind "reload_btn" "click" restart_daemon)
	 (form-bind "update_btn" "click" update_bases)
	 (form-bind "use_key_btn" "click" write_key)
	 (form-bind "cansel_key_btn" "click" drop_key)
	 (form-bind "quarantine_btn" "click" inspect)
	 (form-bind "update_period" "change" change_cron)
	 (form-bind "enable_samba" "change" write_samba)
	 (form-bind-upload "upload_key_btn" "click" "key_file" on-upload))
        (begin
         (form-update-visibility "alert" #t)
         (form-update-visibility "main" #f)
        )))
