(define-module (ui drweb quarantine ajax)
    :use-module (alterator woo)
    :use-module (alterator ajax)
    :use-module (alterator str)
    :use-module (alterator algo)
  :export (init))

(define *per-page* 10)
(define *start-line* 1)
(define *end-line* 11)
(define *total-lines* 123)

(define (return)
    (form-replace "/drweb"))
    
(define (do-update)
    (form-update-value "start_l" *start-line*)
    (form-update-value "end_l" *end-line*)
    (form-update-enum "qfiles" '())
    (form-update-enum "qfiles" (woo-list "/drweb/qlist" 
	'start *start-line*
	'size *per-page*
	'language (form-value "language")
	))
    (form-update-value "start_l" *start-line*)
    (form-update-value "end_l" *end-line*)
)

(define (ui-init)
    (form-update-enum "per_page" (woo-list "/drweb/selector" 'language (form-value "language")))
    (form-update-value-list '("total" "per_page") (woo-read-first "/drweb/pager" 'language (form-value "language")))

    (set! *total-lines* (string->number(form-value "total")))
    (set! *per-page* (string->number(form-value "per_page")))
    (if (< *total-lines* *per-page*) 
	(begin 
	    (set! *end-line* *total-lines*)
	    (form-update-visibility "buttons" #f))
	(begin
	    (set! *end-line* (+ *start-line* *per-page*))
	    (form-update-visibility "buttons" #t))
    )
    (do-update)
)
    
(define (delete_selected)
    (catch/message
	(lambda()
    	    (apply woo-delete "/drweb/filelist"
                'language (form-value "language")
                (form-value-list '("qfiles" "name")))
    (ui-init)))
)

(define (go-first) 
    (set! *start-line* 1)
    (set! *end-line* (+ *start-line* *per-page*))
    (if (< *total-lines* *end-line*) (set! *end-line* *total-lines*))
    (do-update))

(define (go-back) 
    (set! *start-line* (- *start-line* *per-page*))
    (if (< *start-line* 1) (set! *start-line* 1))
    (set! *end-line* (+ *start-line* *per-page*))
    (if (< *total-lines* *end-line*) (set! *end-line* *total-lines*))
    (do-update))

(define (go-next)
    (set! *end-line* (+ *end-line* *per-page*))
    (if (> *end-line* *total-lines*) (set! *end-line* *total-lines*))
    (set! *start-line* (- *end-line* *per-page*))
    (if (< *start-line* 1) (set! *start-line* 1))
    (do-update))

(define (go-last) 
    (set! *end-line* *total-lines*)
    (set! *start-line* (- *total-lines* *per-page*))
    (if (< *start-line* 1) (set! *start-line* 1))
    (do-update))

(define (do-size)
    (set! *per-page* (string->number(form-value "per_page")))
    (if (< *total-lines* *per-page*) 
	(set! *end-line* *total-lines*)
	(set! *end-line* (+ *start-line* *per-page*)))
    (do-update))


(define (init)
    (ui-init)
    (form-bind "q_selected_btn" "click" delete_selected)
    (form-bind "ret_btn" "click" return)
    (form-bind "back_button" "click" go-back)
    (form-bind "next_button" "click" go-next)
    (form-bind "first_button" "click" go-first)
    (form-bind "last_button" "click" go-last)
    (form-bind "per_page" "change" do-size)

)
